@@ -1,8 +1,8 @@
 """ log all requests """
-from tools.logs import log
+from mim.tools.logs import log
 
 # callbacks
-from tools.pydispatch2 import on
+from mim.tools.pydispatch2 import on
 from mim.proxyserver import gotRequest
 from mim.proxyclient import gotResponseTree
 
