@@ -3,17 +3,17 @@
     usage:
         reactor.listenTCP(port, proxyserver.ProxyFactory())
 """
-from tools.logs import log
+from mim.tools.logs import log
 import logging
 from urlparse import urlparse
 import os
 import tldextract
-from tools.tools import zips
+from mim.tools.tools import zips
 
 from twisted.internet import reactor, ssl
 from twisted.web import http
-from proxyclient import ProxyClientFactory
-from tools.pydispatch2 import Signal
+from mim.proxyclient import ProxyClientFactory
+from mim.tools.pydispatch2 import Signal
 
 gotRequest = Signal("gotRequest")
 
